==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Перевищено час очікування на розпізнавання</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Диск зайнятий, його неможливо розмонтувати зараз</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Диск зайнятий, зараз його неможливо вийняти</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Пристрій зайнято, його не можна виштовхнути зараз</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Пристрій зайнято, зараз вилучення неможливе</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Том %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Невідомо</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Пристрій не було безпечно вилучено</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Наступного разу натисніть кнопку «Вилучити безпечно», а вже потім від&apos;єднуйте пристрій</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Пристрій зайнято, його не можна виштовхнути зараз</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Пристрій зайнято, зараз вилучення неможливе</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Не вдалося демонтувати пристрій</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Диск змонтовано користувачем %1, ви не можете розмонтувати його.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Не вдалося знайти змонтований пристрій</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Диски</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Виштовхнути усі</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Пристрій було безпечно вилучено</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Доступ заборонено</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>У вас немає дозволу на доступ до цієї теки</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Скануємо пристрій. Припинити?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Припинити</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.5.10.orig.tar.xz: dde-file-manager-5.5.10/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Перевищено час очікування на розпізнавання</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Диск зайнятий, його неможливо розмонтувати зараз</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Диск зайнятий, зараз його неможливо вийняти</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Пристрій зайнято, його не можна виштовхнути зараз</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Пристрій зайнято, зараз вилучення неможливе</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Том %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Невідомо</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Пристрій не було безпечно вилучено</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Наступного разу натисніть кнопку «Вилучити безпечно», а вже потім від&apos;єднуйте пристрій</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Не вдалося демонтувати пристрій</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Диск змонтовано користувачем %1, ви не можете розмонтувати його.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Не вдалося знайти змонтований пристрій</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Диски</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Виштовхнути усі</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Пристрій було безпечно вилучено</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Доступ заборонено</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>У вас немає дозволу на доступ до цієї теки</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Скануємо пристрій. Припинити?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Підтвердити</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Припинити</translation>
    </message>
</context>
</TS>
